darkhistory.utilities.hyp2f1_func_real — DarkHistory documentation

# darkhistory.utilities.hyp2f1_func_real

`darkhistory.utilities.` `hyp2f1_func_real`(n, x)

  Returns the real part of \(_2F_1(1, n+1, n+2, x)\).

  Avoids the need for complex numbers in `scipy.special.hyp2f1`, which is very slow. The function definition is identical.

  Parameters: | n : integer The order of \(_2F_1(1, n+1, n+2, x)\) to evaluate. x : ndarray The main argument of the function.
  Returns: | ndarray The result of \(_2F_1(1, n+1, n+2, x)\).

#### Previous topic

darkhistory.utilities.get_grid

#### Next topic

darkhistory.utilities.is_log_spaced

### This Page

Show Source